@@ -1,34 +1,29 @@
 package Catmandu::Fix::xml_transform;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Catmandu::Sane;
 use Moo;
-use XML::LibXML;
-use XML::LibXSLT;
-
+use Catmandu::Fix::Has;
 use Catmandu::XML::Transformer;
 
 with 'Catmandu::Fix::Base';
 
-has field       => (is => 'ro', required => 1);
-has file        => (is => 'ro', required => 1);
+has field   => (fix_arg => 1);
+has file    => (fix_opt => 1);
+has format  => (fix_opt => 1);
 
 has _transformer => (
     is => 'ro',
     lazy => 1,
     default => sub {
         Catmandu::XML::Transformer->new( 
-            stylesheet => $_[0]->file 
+            stylesheet => $_[0]->file,
+            output_format => $_[0]->format,
         );
     }
 );
 
-around BUILDARGS => sub {
-    my($orig,$class,$field,%opts) = @_;
-    $orig->($class,field => $field, file => $opts{file});
-};
-
 sub emit {    
     my ($self,$fixer) = @_;    
 
@@ -63,9 +58,27 @@ Catmandu::Fix::xml_transform - transform XML using XSLT stylesheet
 This L<Catmandu::Fix> transforms XML with an XSLT stylesheet. Based on
 L<Catmandu::XML::Transformer> the fix will transform and XML string into an XML
 string, MicroXML (L<XML::Struct>) into MicroXML, and a DOM into a DOM. If the
-stylesteet is intented to emit text (C<<  <xsl:output method="text"/> >>,
+stylesheet is intented to emit text (C<<  <xsl:output method="text"/> >>,
 however, this fix I<always> transforms produces a string.
 
 One ore multiple XSLT scripts can be specified with argument C<file>.
 
+=head1 CONFIGURATION
+
+=over
+
+=item field
+
+Data field to get XML from
+
+=item file
+
+One or more file names of optional XSLT scripts
+
+=item format
+
+Optional output format (C<string>, C<struct>, C<simple>, or C<dom>)
+
+=back
+
 =cut
